from setuptools import setup,find_packages

setup(
    name='roshanhelloworld',
    author='roshan bhatta',
    author_email='bhattaroshan@gmail.com',
    version='1.0.4',
    packages=find_packages()
)